require_relative "player"
require_relative "card"
require_relative "die"
require_relative "game_turn"

module CardGame
    class Game
        
        attr_reader :name, :players
        
        def initialize(name)
            @name = name.capitalize
            @players = []
            @round = 20
        end
        
        def add_players(player)
            @players.push(player)
        end
        
        def play(rounds)
            1.upto(rounds) do |round| 
                GameTurn.turn(@players) 
            end
        end
        
        def save_score(to_file = "high_score.txt")
            name = "Name".ljust(10)
            rank = "Rank".ljust(10)
            gold = "Gold".ljust(10)
            score = "Score".ljust(10)
            sorted_players = @players.sort
            puts "Saving high score into #{to_file}"
            File.open(to_file, "w") do |file|
                file.puts "#{@name}'s High scores"
                file.puts "#{name}#{rank}#{gold}#{score}"
                sorted_players.each do |player|
                    file.puts "#{player.name.ljust(10)}#{String(player.rank).ljust(10)}#{String(player.gold).ljust(10)}#{String(player.score).ljust(10)}"
                end
            end
        end
        
        def print_stats
            sorted_players = @players.sort
            sorted_players.each do |player|
                puts "\n"
                puts player
                puts "#{player.name}'s Deck:"
                sorted_deck = player.deck.sort
                sorted_deck .each do |card|
                       puts "Name: #{card.name.to_s.capitalize}\t Health: #{card.health}\t Damage: #{card.damage}" 
                end
            end
        end
    end
    
    
    if __FILE__ ==$0
        player1 = Player.new("moe")
        player2 = Player.new("larry")
        player3 = Player.new("joe")
        
        clash_royale = Game.new("clash_royale")
        clash_royale.add_players(player1)
        clash_royale.add_players(player2)
        clash_royale.add_players(player3)
        
        clash_royale.play(1)
        clash_royale.print_stats
        
    
    end
end